Trait Abs
Source pub trait Abs {
type Output;
// Required method
fn abs(self) -> Self::Output;
}
This trait provides the interface for the function used to compute the absolute value of a number.
The return type of the absolute value function. It is always a real number (also when the input is a complex number).
Returns the absolute value of self. The return type is always a real number (also when self is a complex number)
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
SourceImplementation of the Abs trait for Complex<f64>.
The return type of the absolute value function.
Returns the absolute value of self.
The return type of the absolute value function.
Returns the absolute value of self.