pub struct Native64;Expand description
Numerical kernel specifier to be used as generic argument (or associated type) in order to indicate
that the floating point values that must be used are the Rust’s native f64 and/or Complex<f64>.