ATanH

Trait ATanH 

pub trait ATanH {
    // Required method
    fn atanh_(self) -> Self;
}
This trait provides the interface for the inverse hyperbolic tangent function.

Required Methods

fn atanh_(self) -> Self

Computes the inverse hyperbolic tangent of self, rounding to the nearest.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl ATanH for f64

Source

fn atanh_(self) -> Self

Computes the inverse hyperbolic tangent of self, rounding to the nearest.

Source

impl ATanH for Complex<f64>

Source

fn atanh_(self) -> Self

Computes the inverse hyperbolic tangent of self, rounding to the nearest.

Implementors