CosH

Trait CosH 

pub trait CosH {
    // Required method
    fn cosh_(self) -> Self;
}
This trait provides the interface for the hyperbolic cosine function.

Required Methods

fn cosh_(self) -> Self

Computes the hyperbolic cosine of self, rounding to the nearest.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl CosH for f64

Source

fn cosh_(self) -> Self

Computes the hyperbolic cosine of self, rounding to the nearest.

Source

impl CosH for Complex<f64>

Source

fn cosh_(self) -> Self

Computes the hyperbolic cosine of self, rounding to the nearest.

Implementors