IsFinite

Trait IsFinite 

pub trait IsFinite {
    // Required method
    fn is_finite_(&self) -> bool;
}
This trait provides the interface for the function used to check if a number is finite (i.e. neither infinite or NaN).

Required Methods

fn is_finite_(&self) -> bool

Returns true if self is neither infinite nor NaN.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IsFinite for Complex<f64>

Source

fn is_finite_(&self) -> bool

Returns true if self is neither infinite nor NaN.

Source

impl IsFinite for f64

Source

fn is_finite_(&self) -> bool

Returns true if self is neither infinite nor NaN.

Implementors