IsInfinite

Trait IsInfinite 

pub trait IsInfinite {
    // Required method
    fn is_infinite_(&self) -> bool;
}
This trait provides the interface for the function used to check if a number is infinite.

Required Methods

fn is_infinite_(&self) -> bool

Returns true if self is positive infinity or negative infinity.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IsInfinite for Complex<f64>

Source

fn is_infinite_(&self) -> bool

Returns true if self is positive infinity or negative infinity, and false otherwise.

Source

impl IsInfinite for f64

Source

fn is_infinite_(&self) -> bool

Returns true if self is positive infinity or negative infinity, and false otherwise.

Implementors