IsNormal

Trait IsNormal 

pub trait IsNormal {
    // Required method
    fn is_normal_(&self) -> bool;
}
This trait provides the interface for the function used to check if a number is normal (i.e. neither zero, infinite, subnormal, or NaN).

Required Methods

fn is_normal_(&self) -> bool

Returns true if self is normal (i.e. neither zero, infinite, subnormal, or NaN).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IsNormal for Complex<f64>

Source

fn is_normal_(&self) -> bool

Returns true if self is normal (i.e. neither zero, infinite, subnormal, or NaN).

Source

impl IsNormal for f64

Source

fn is_normal_(&self) -> bool

Returns true if self is normal (i.e. neither zero, infinite, subnormal, or NaN).

Implementors