Log10

Trait Log10 

pub trait Log10 {
    // Required method
    fn log10_(self) -> Self;
}
This trait provides the interface for the common logarithm function.

Required Methods

fn log10_(self) -> Self

Computes the common logarithm of self, rounding to the nearest.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl Log10 for f64

Source

fn log10_(self) -> Self

Computes the common logarithm of self, rounding to the nearest.

Source

impl Log10 for Complex<f64>

Source

fn log10_(self) -> Self

Computes the common logarithm of self, rounding to the nearest.

Implementors