MulComplexLeft

Trait MulComplexLeft 

pub trait MulComplexLeft<T: NumKernel>:
    Mul<T::RealType, Output = T::ComplexType>
    + for<'a> Mul<&'a T::RealType, Output = T::ComplexType>
    + MulAssign<T::RealType>
    + for<'a> MulAssign<&'a T::RealType> { }
Trait for the multiplication between a complex number (on the left hand side) and a real number (on the right hand side). The result of these binary operation will be always a complex number.

Note

We only permit multiplication between complex and real numbers. Addition and subtraction of a complex number with a real number is not allowed for safety reasons.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl MulComplexLeft<Native64> for Complex<f64>

Implementors