NumKernel

Trait NumKernel 

pub trait NumKernel:
    Clone
    + Debug
    + PartialEq
    + Sync {
    type RawRealType: Sized + Debug + RealValueValidator + PartialOrd<f64>;
    type RawComplexType: Sized + Debug + ComplexValueValidator<RealType = Self::RawRealType>;
    type RealType: FunctionsRealType<Self> + Serialize + DeserializeOwned;
    type ComplexType: FunctionsComplexType<Self> + Serialize + DeserializeOwned;
}
Trait used to indicate the type of floating point number that is used.

Required Associated Types

type RawRealType: Sized + Debug + RealValueValidator + PartialOrd<f64>

type RawComplexType: Sized + Debug + ComplexValueValidator<RealType = Self::RawRealType>

type RealType: FunctionsRealType<Self> + Serialize + DeserializeOwned

The type for a real scalar value in this numerical kernel.

type ComplexType: FunctionsComplexType<Self> + Serialize + DeserializeOwned

The type for a complex scalar value in this numerical kernel.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors