pub struct NeumaierSumReal<T: NumKernel> { /* private fields */ }Expand description
Neumaier compensated sum of an iterable object of floating-point numbers.
When summing floating-point values in a vector, the standard method of adding values sequentially can lead to precision loss, especially when there are a large number of elements or a mix of very large and very small values. This happens because floating-point arithmetic is not associative due to rounding errors. The most accurate algorithm to sum floating-point numbers typically avoids these precision problems.
Kahan summation is a popular algorithm that reduces numerical errors when adding a sequence of floating-point numbers. It keeps track of a running compensation for lost low-order bits during summation.
Neumaier summation is a slight modification of Kahan summation that can handle larger errors better. It uses an extra step to correct for the compensation term if the summation results in a larger round-off error than Kahan’s method can correct.
Example
use ftl_numkernel::{
Native64,
neumaier_compensated_sum::{NeumaierSum,NeumaierSumReal}
};
let mut neumaier = NeumaierSumReal::<Native64>::zero();
neumaier.add(1.0);
neumaier.add(1e100);
neumaier.add(1.0);
neumaier.add(-1e100);
let sum = neumaier.sum();
println!("Sum: {}", sum);
assert_eq!(sum, 2.0);References