pub trait IsFinite {
// Required method
fn is_finite_(&self) -> bool;
}Expand description
This trait provides the interface for the function used to check if a number is finite (i.e. neither infinite or NaN).
Required Methods
Sourcefn is_finite_(&self) -> bool
fn is_finite_(&self) -> bool
Returns true if self is neither infinite nor NaN.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl IsFinite for Complex<f64>
impl IsFinite for Complex<f64>
Sourcefn is_finite_(&self) -> bool
fn is_finite_(&self) -> bool
Returns true if self is neither infinite nor NaN.
Sourceimpl IsFinite for f64
impl IsFinite for f64
Sourcefn is_finite_(&self) -> bool
fn is_finite_(&self) -> bool
Returns true if self is neither infinite nor NaN.