pub trait IsInfinite {
// Required method
fn is_infinite_(&self) -> bool;
}Expand description
This trait provides the interface for the function used to check if a number is infinite.
Required Methods
Sourcefn is_infinite_(&self) -> bool
fn is_infinite_(&self) -> bool
Returns true if self is positive infinity or negative infinity.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl IsInfinite for Complex<f64>
impl IsInfinite for Complex<f64>
Sourcefn is_infinite_(&self) -> bool
fn is_infinite_(&self) -> bool
Returns true if self is positive infinity or negative infinity, and false otherwise.
Sourceimpl IsInfinite for f64
impl IsInfinite for f64
Sourcefn is_infinite_(&self) -> bool
fn is_infinite_(&self) -> bool
Returns true if self is positive infinity or negative infinity, and false otherwise.