pub trait IsNormal {
// Required method
fn is_normal_(&self) -> bool;
}Expand description
This trait provides the interface for the function used to check if a number is normal (i.e. neither zero, infinite, subnormal, or NaN).
Required Methods
Sourcefn is_normal_(&self) -> bool
fn is_normal_(&self) -> bool
Returns true if self is normal (i.e. neither zero, infinite, subnormal, or NaN).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl IsNormal for Complex<f64>
impl IsNormal for Complex<f64>
Sourcefn is_normal_(&self) -> bool
fn is_normal_(&self) -> bool
Returns true if self is normal (i.e. neither zero, infinite, subnormal, or NaN).
Sourceimpl IsNormal for f64
impl IsNormal for f64
Sourcefn is_normal_(&self) -> bool
fn is_normal_(&self) -> bool
Returns true if self is normal (i.e. neither zero, infinite, subnormal, or NaN).