pub trait Log10 {
// Required method
fn log10_(self) -> Self;
}Expand description
This trait provides the interface for the common logarithm function.
Required Methods
Sourcefn log10_(self) -> Self
fn log10_(self) -> Self
Computes the common logarithm of self, rounding to the nearest.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl Log10 for f64
impl Log10 for f64
Sourcefn log10_(self) -> Self
fn log10_(self) -> Self
Computes the common logarithm of self, rounding to the nearest.
Sourceimpl Log10 for Complex<f64>
impl Log10 for Complex<f64>
Sourcefn log10_(self) -> Self
fn log10_(self) -> Self
Computes the common logarithm of self, rounding to the nearest.