pub trait MulComplexRight<T: NumKernel>: Mul<T::ComplexType, Output = T::ComplexType> { }Expand description
Trait for the multiplication between a real number (on the left hand side) and a complex number (on the right hand side). The result of these binary operation will be always a complex number.
Note
We only permit multiplication between real and complex numbers. Addition and subtraction of a real number with a complex number is not allowed for safety reasons.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".